@@ -1,4 +1,8 @@
-#[derive(Debug, Clone)]
+use std::result;
+
+pub type Result<T> = result::Result<T, Error>;
+
+#[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum Error {
     PacketSize,
     NumberConversion,
